<template>
    <div class="device-status">
        <div class="header">
            <div class="header-title">{{ title }}</div>
        </div>
        <div class="item-container">
            <img :src="getImage('/device-overview/lszt@2x.png')" alt="" />
            <!-- <span class="title">系统是否漏水</span> -->
            <span class="status">{{ statusTxt }}</span>
            <div v-if="status == 0" class="desc-tips">
                {{ warningDesc }}
            </div>
            <div v-if="status == 1" class="desc-tips warning">
                <img
                    :src="getImage('/device-overview/kqjc/warning@2x.png')"
                    alt=""
                />
                {{ warningDesc }}
            </div>
        </div>
    </div>
</template>
<script lang="ts" name="DeviceRuningStatus" setup>
import { getImage } from '@/utils/comm';

const props = defineProps({
    typeId: {
        type: [Number],
        default: 1401,
    },
});
const title = ref<string>('');
const status = ref<number>(0);
const statusTxt = ref<string>('');
const warningDesc = ref<string>('');

onMounted(() => {
    if (props.typeId == 1201) {
        title.value = '运行状态';
        status.value = 0;
        statusTxt.value = '正常';
        warningDesc.value = '烟雾报警';
    }
    if (props.typeId == 1211) {
        title.value = '运行状态';
        status.value = 0;
        statusTxt.value = '正常';
        warningDesc.value = '消防报警';
    }
    if (props.typeId == 1401) {
        title.value = '漏水状态';
        status.value = 1;
        statusTxt.value = '漏水';
        warningDesc.value = '漏水状态';
    }
});

// const props = defineProps({});
</script>
<style scoped lang="less">
.device-status {
    width: 100%;
    height: 100%;
    padding: 16px;
    background: #ffffff;
    box-shadow: 0px 2px 6px 0px #cccccc;
    border-radius: 4px 4px 4px 4px;
    .header {
        display: flex;
        align-items: center;
        justify-content: space-between;
        .header-title {
            border-left: 3px solid #3468ff;
            padding-left: 8px;
            font-size: 16px;
            font-family: PingFang SC-Medium, PingFang SC;
            font-weight: 500;
            color: #333333;
            line-height: 23px;
        }
    }
    .item-container {
        display: flex;
        flex-direction: column;
        align-items: center;
        justify-content: center;
        position: relative;
        > img {
            width: 239px;
            height: 239px;
        }
        .title {
            position: absolute;
            top: 70px;
            font-size: 16px;
            font-family: PingFang SC-Medium, PingFang SC;
            font-weight: 500;
            color: #ffffff;
            line-height: 23px;
        }
        .status {
            position: absolute;
            top: 108px;
            left: calc(50% - 10px);
            font-size: 32px;
            font-family: PingFang SC-Semibold, PingFang SC;
            font-weight: 600;
            color: #ffffff;
            line-height: 23px;
        }

        .desc-tips {
            display: flex;
            align-items: center;
            justify-content: center;
            margin-top: 24px;
            width: 295px;
            height: 40px;
            background: linear-gradient(
                267deg,
                #ffffff 0%,
                #c2eaff 50%,
                #ffffff 100%
            );
            font-size: 18px;
            font-family: PingFang SC-Medium, PingFang SC;
            font-weight: 500;
            color: #222222;
            line-height: 23px;
            &.warning {
                color: #fa3e2e;
                background: linear-gradient(
                    267deg,
                    #ffffff 0%,
                    #ffc7c2 50%,
                    #ffffff 100%
                );
            }

            img {
                width: 20px;
                height: 20px;
            }
        }
    }
}
</style>
